@@ -4,7 +4,7 @@ package AuthCAS;
 use strict;
 use vars qw( $VERSION);
 
-$VERSION = '1.4.1';
+$VERSION = '1.1';
 
 =head1 NAME
 
@@ -12,7 +12,7 @@ AuthCAS - Client library for CAS 2.0 authentication server
 
 =head1 VERSION
 
-Version 1.4.1
+Version 1.1
 
 =head1 DESCRIPTION
 
@@ -216,16 +216,16 @@ sub _parse_xml {
 
     my %xml_struct;
 
-    while ($data =~ /^<([^\s>]+)(\s+[^\s>]+)*>([\s\S\n]*)(<\/\1>)/m) {
+    while ($data =~ /^<([^\s>]+)(\s+[^\s>]+)?>([\s\S\n]*)(<\/\1>)/m) {
 	my ($new_tag, $new_data) = ($1,$3);
 	chomp $new_data;
 	$new_data =~ s/^[\s\n]+//m;
-	$data =~ s/^<$new_tag(\s+[^\s>]+)*>([\s\S\n]*)(<\/$new_tag>)//m;
+	$data =~ s/^<$new_tag(\s+[^\s>]+)?>([\s\S\n]*)(<\/$new_tag>)//m;
 	$data =~ s/^[\s\n]+//m;
 	
 	## Check if data still includes XML tags
 	my $struct;
-	if ($new_data =~/^<([^\s>]+)(\s+[^\s>]+)*>([\s\S\n]*)(<\/\1>)/m) {
+	if ($new_data =~/^<([^\s>]+)(\s+[^\s>]+)?>([\s\S\n]*)(<\/\1>)/m) {
 	    $struct = &_parse_xml($new_data);
 	}else {
 	    $struct = $new_data;
@@ -375,11 +375,6 @@ sub callCAS {
     
     my @xml = &get_https2($host, $port, $path,{'cafile' =>  $self->{'CAFile'},  'capath' => $self->{'CAPath'}});
 
-    unless (@xml) {
-	warn $errors;
-	return undef;
-    }
-
     ## Skip HTTP header fields
     my $line = shift @xml;
     while ($line !~ /^\s*$/){
@@ -440,17 +435,15 @@ sub get_https2{
 	    return undef;
 	}
 	
-	unless (eval "require IO::Socket::SSL") {
+	unless (require IO::Socket::SSL) {
 	    $errors = sprintf "Unable to use SSL library, IO::Socket::SSL required, install IO-Socket-SSL (CPAN) first\n";
 	    return undef;
 	}
-	require IO::Socket::SSL;
-
-	unless (eval "require LWP::UserAgent") {
+	
+	unless (require LWP::UserAgent) {
 	    $errors = sprintf "Unable to use LWP library, LWP::UserAgent required, install LWP (CPAN) first\n";
 	    return undef;
 	}
-	require  LWP::UserAgent;
 
 	my $ssl_socket;
 
@@ -474,8 +467,8 @@ sub get_https2{
 	    return undef;
 	}
 	
-	my $request = "GET $path HTTP/1.0\r\nHost: $host\r\n\r\n";
-	print $ssl_socket "$request";
+	my $request = "GET $path HTTP/1.0\n\n";
+	print $ssl_socket "$request\n\n";
 
 	my @result;
 	while (my $line = $ssl_socket->getline) {
